@@ -18,47 +18,45 @@ from c_formatter_42.formatters import helper
 
 
 class Scope(Enum):
-    LOCAL  = 0
+    LOCAL = 0
     GLOBAL = 1
 
 
 def align_scope(content: str, scope: Scope) -> str:
-    """ Align content
-        scope can be either local or global
-          local:  for variable declarations in function
-          global: for function prototypes
+    """Align content
+    scope can be either local or global
+      local:  for variable declarations in function
+      global: for function prototypes
     """
 
     lines = content.split("\n")
     aligned = []
     # select regex according to scope
     if scope is Scope.LOCAL:
-        align_regex = (
-            "^\t"
-            r"(?P<prefix>{type})\s+"
-            r"(?P<suffix>\**{decl};)$"
-        )
+        align_regex = "^\t" r"(?P<prefix>{type})\s+" r"(?P<suffix>\**{decl};)$"
     elif scope is Scope.GLOBAL:
         align_regex = (
             r"^(?P<prefix>{type})\s+"
             r"(?P<suffix>({name}\(.*\)?;?)|({decl}(;|(\s+=\s+.*))))$"
         )
     align_regex = align_regex.format(
-        type=helper.REGEX_TYPE,
-        name=helper.REGEX_NAME,
-        decl=helper.REGEX_DECL_NAME
+        type=helper.REGEX_TYPE, name=helper.REGEX_NAME, decl=helper.REGEX_DECL_NAME
     )
     # get the lines to be aligned
     matches = [re.match(align_regex, line) for line in lines]
-    aligned = [(i, match.group("prefix"), match.group("suffix"))
-               for i, match in enumerate(matches)
-               if match is not None and
-               match.group("prefix") not in ["struct", "union", "enum"]]
+    aligned = [
+        (i, match.group("prefix"), match.group("suffix"))
+        for i, match in enumerate(matches)
+        if match is not None
+        and match.group("prefix") not in ["struct", "union", "enum"]
+    ]
 
     # global type declaration (struct/union/enum)
     if scope is Scope.GLOBAL:
-        typedecl_open_regex  = (r"^(?P<prefix>\s*(typedef\s+)?(struct|enum|union))"
-                                r"\s*(?P<suffix>[a-zA-Z_]\w+)?$")
+        typedecl_open_regex = (
+            r"^(?P<prefix>\s*(typedef\s+)?(struct|enum|union))"
+            r"\s*(?P<suffix>[a-zA-Z_]\w+)?$"
+        )
         typedecl_close_regex = r"^(?P<prefix>\})\s*(?P<suffix>([a-zA-Z_]\w+)?;)$"
         in_type_scope = False
         for i, line in enumerate(lines):
@@ -77,9 +75,10 @@ def align_scope(content: str, scope: Scope) -> str:
             if in_type_scope:
                 m = re.match(
                     r"^(?P<prefix>\s+{type})\s+"
-                    r"(?P<suffix>\**{decl};)$"
-                    .format(type=helper.REGEX_TYPE, decl=helper.REGEX_DECL_NAME),
-                    line
+                    r"(?P<suffix>\**{decl};)$".format(
+                        type=helper.REGEX_TYPE, decl=helper.REGEX_DECL_NAME
+                    ),
+                    line,
                 )
                 if m is not None:
                     aligned.append((i, m.group("prefix"), m.group("suffix")))
@@ -87,7 +86,7 @@ def align_scope(content: str, scope: Scope) -> str:
     # get the minimum alignment required for each line
     min_alignment = max(
         (len(prefix.replace("\t", " " * 4)) // 4 + 1 for _, prefix, _ in aligned),
-        default=1
+        default=1,
     )
     for i, prefix, suffix in aligned:
         alignment = len(prefix.replace("\t", " " * 4)) // 4
@@ -99,12 +98,12 @@ def align_scope(content: str, scope: Scope) -> str:
 
 @helper.locally_scoped
 def align_local(content: str) -> str:
-    """ Wrapper for align_scope to use local_scope decorator """
+    """Wrapper for align_scope to use local_scope decorator"""
     return align_scope(content, scope=Scope.LOCAL)
 
 
 def align(content: str) -> str:
-    """ Align the content in global and local scopes """
+    """Align the content in global and local scopes"""
     content = align_scope(content, scope=Scope.GLOBAL)
     content = align_local(content)
     return content
