@@ -14,15 +14,15 @@ import re
 
 
 # regex for a type
-REGEX_TYPE      = r"(?!return)([a-z]+\s+)*[a-zA-Z_]\w*"
+REGEX_TYPE = r"(?!return)([a-z]+\s+)*[a-zA-Z_]\w*"
 # regex for a c variable/function name
-REGEX_NAME      = r"\**[a-zA-Z_*()]\w*"
+REGEX_NAME = r"\**[a-zA-Z_*()]\w*"
 # regex for a name in a declaration context (with array and function ptr)
 REGEX_DECL_NAME = r"\(?{name}(\[.*\])*(\)\(.*\))?".format(name=REGEX_NAME)
 
 
 def locally_scoped(func):
-    """ Apply the formatter on every local scopes of the content """
+    """Apply the formatter on every local scopes of the content"""
 
     def wrapper(content: str) -> str:
         def get_replacement(match):
@@ -38,6 +38,7 @@ def locally_scoped(func):
             r"\)\n\{(?P<body>.*?)\n\}\n".replace(r"\n", "\n"),
             get_replacement,
             content,
-            flags=re.DOTALL
+            flags=re.DOTALL,
         )
+
     return wrapper
